%define _buildid .1

%global py26nvr python26-boto-%{version}-%{release}
%global py26builddir %{_builddir}/%{py26nvr}
%global py26doc ../%{py26nvr}

%global py27nvr python27-boto-%{version}-%{release}
%global py27builddir %{_builddir}/%{py27nvr}
%global py27doc ../%{py27nvr}

# Tests require AWS credentials
%bcond_with tests # without

%global upstream_name boto

Name: python-boto
Version: 2.42.0
Release: 1%{?_buildid}%{?dist}
Summary: Python interface to Amazon Web Services
Group: Development/Languages
License: MIT
URL: http://aws.amazon.com/sdkforpython/
Source: https://github.com/boto/boto/archive/%{version}.tar.gz
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python26
BuildRequires: python27

%description
Boto is a Python library that provides an easy to use interface to Amazon Web
Services(AWS). It supports interfacing with all AWS services. This package also
includes a number of command line tools which can be used to perform typical
tasks with AWS as well as provide examples on how to use Boto.

%package -n python26-boto
Summary: Python interface to Amazon Web Services
BuildRequires: python26-devel
BuildRequires: python26-setuptools
BuildRequires: python26-nose
BuildRequires: python26-argparse
BuildRequires: python26-mock
Requires: python26(alternatives)
Requires: alternatives(addslave)
Requires: alternatives(removeslave)
Requires: alternatives(force)
Requires(preun): python26(alternatives)
Requires(preun): alternatives(removeslave)
Requires: python26-requests >= 1.2.3
Requires: python26-requests <= 2.0.1
Requires: python26-rsa >= 3.1.1
Requires: python26-simplejson >= 3.6.5
Requires: python26-argparse >= 1.2.1
Requires: python26-paramiko >= 1.7.5
Provides: python-boto = %{version}-%{release}
Provides: bundled(python-six) = 1.9.0
Obsoletes: python-boto <= 2.36.0-1.2.amzn1

%description -n python26-boto
Boto is a Python library that provides an easy to use interface to Amazon Web
Services(AWS). It supports interfacing with all AWS services. This package also
includes a number of command line tools which can be used to perform typical
tasks with AWS as well as provide examples on how to use Boto.

This package is meant to be used with Python 2.6.

%package -n python27-boto
Summary: Python interface to Amazon Web Services
BuildRequires: python27-devel
BuildRequires: python27-setuptools
BuildRequires: python27-nose
BuildRequires: python27-mock
Requires: python27(alternatives)
Requires: alternatives(addslave)
Requires: alternatives(removeslave)
Requires: alternatives(force)
Requires(preun): python27(alternatives)
Requires(preun): alternatives(removeslave)
Requires: python27-requests >= 1.2.3
Requires: python27-requests <= 2.0.1
Requires: python27-rsa >= 3.1.1
Requires: python27-simplejson >= 3.6.5
Requires: python27-paramiko >= 1.7.5
Provides: bundled(python-six) = 1.9.0
Conflicts: python-boto <= 2.36.0-1.2.amzn1

%description -n python27-boto
Boto is a Python library that provides an easy to use interface to Amazon Web
Services(AWS). It supports interfacing with all AWS services. This package also
includes a number of command line tools which can be used to perform typical
tasks with AWS as well as provide examples on how to use Boto.

This package is meant to be used with Python 2.7.

%prep
%setup -q -n %{upstream_name}-%{version}

%build
rm -rf %{py26builddir}
mkdir -p %{py26builddir}
cp -a * %{py26builddir}
pushd %{py26builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python26} setup.py build 
popd

rm -rf %{py27builddir}
mkdir -p %{py27builddir}
cp -a * %{py27builddir}
pushd %{py27builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python27} setup.py build 
popd

%install
rm -rf %{buildroot}

pushd %{py26builddir}
%{__python26} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd

# Set up versioned scripts and fix shebangs for python 2.6
for script in \
      asadmin bundle_image cfadmin cq cwutil dynamodb_dump dynamodb_load \
      elbadmin fetch_file glacier instance_events kill_instance \
      launch_instance list_instances lss3 mturk pyami_sendmail route53 s3put \
      sdbadmin taskadmin \
; do
   mv %{buildroot}%{_bindir}/${script}{,-2.6}
   %{__python26_shebang} %{buildroot}%{_bindir}/${script}-2.6
done

for file in pyami/launch_ami.py services/bs.py services/result.py; do
   %{__python26_shebang} %{buildroot}%{python26_sitelib}/%{upstream_name}/${file}
done

pushd %{py27builddir}
%{__python27} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd

# Set up versioned scripts and fix shebangs for python 2.7
for script in \
      asadmin bundle_image cfadmin cq cwutil dynamodb_dump dynamodb_load \
      elbadmin fetch_file glacier instance_events kill_instance \
      launch_instance list_instances lss3 mturk pyami_sendmail route53 s3put \
      sdbadmin taskadmin \
; do
   mv %{buildroot}%{_bindir}/${script}{,-2.7}
   %{__python27_shebang} %{buildroot}%{_bindir}/${script}-2.7
done

for file in pyami/launch_ami.py services/bs.py services/result.py; do
   %{__python27_shebang} %{buildroot}%{python27_sitelib}/%{upstream_name}/${file}
done

%check
%if %{with tests}
pushd %{py26builddir}
%{__python26} tests/test.py
popd
pushd %{py27builddir}
%{__python27} tests/test.py
popd
%endif

%clean
rm -rf %{buildroot}
rm -rf %{py26builddir}
rm -rf %{py27builddir}

%triggerin -n python26-boto -- python26
# Refresh alternatives when updating python26-boto or python26.
%{_sbindir}/update-alternatives \
  --force \
  --update python %{_bindir}/python2.6 \
  --addslave %{_bindir}/asadmin asadmin %{_bindir}/asadmin-2.6 \
  --addslave %{_bindir}/bundle_image bundle_image %{_bindir}/bundle_image-2.6 \
  --addslave %{_bindir}/cfadmin cfadmin %{_bindir}/cfadmin-2.6 \
  --addslave %{_bindir}/cq cq %{_bindir}/cq-2.6 \
  --addslave %{_bindir}/cwutil cwutil %{_bindir}/cwutil-2.6 \
  --addslave %{_bindir}/dynamodb_dump dynamodb_dump %{_bindir}/dynamodb_dump-2.6 \
  --addslave %{_bindir}/dynamodb_load dynamodb_load %{_bindir}/dynamodb_load-2.6 \
  --addslave %{_bindir}/elbadmin elbadmin %{_bindir}/elbadmin-2.6 \
  --addslave %{_bindir}/fetch_file fetch_file %{_bindir}/fetch_file-2.6 \
  --addslave %{_bindir}/glacier glacier %{_bindir}/glacier-2.6 \
  --addslave %{_bindir}/instance_events instance_events %{_bindir}/instance_events-2.6 \
  --addslave %{_bindir}/kill_instance kill_instance %{_bindir}/kill_instance-2.6 \
  --addslave %{_bindir}/launch_instance launch_instance %{_bindir}/launch_instance-2.6 \
  --addslave %{_bindir}/list_instances list_instances %{_bindir}/list_instances-2.6 \
  --addslave %{_bindir}/lss3 lss3 %{_bindir}/lss3-2.6 \
  --addslave %{_bindir}/mturk mturk %{_bindir}/mturk-2.6 \
  --addslave %{_bindir}/pyami_sendmail pyami_sendmail %{_bindir}/pyami_sendmail-2.6 \
  --addslave %{_bindir}/route53 route53 %{_bindir}/route53-2.6 \
  --addslave %{_bindir}/s3put s3put %{_bindir}/s3put-2.6 \
  --addslave %{_bindir}/sdbadmin sdbadmin %{_bindir}/sdbadmin-2.6 \
  --addslave %{_bindir}/taskadmin taskadmin %{_bindir}/taskadmin-2.6 \
  || :

%preun -n python26-boto
if [ $1 -eq 0 ]; then
  %{_sbindir}/update-alternatives \
    --update python %{_bindir}/python2.6 \
    --removeslave asadmin \
    --removeslave bundle_image \
    --removeslave cfadmin \
    --removeslave cq \
    --removeslave cwutil \
    --removeslave dynamodb_dump \
    --removeslave dynamodb_load \
    --removeslave elbadmin \
    --removeslave fetch_file \
    --removeslave glacier \
    --removeslave instance_events \
    --removeslave kill_instance \
    --removeslave launch_instance \
    --removeslave list_instances \
    --removeslave lss3 \
    --removeslave mturk \
    --removeslave pyami_sendmail \
    --removeslave route53 \
    --removeslave s3put \
    --removeslave sdbadmin \
    --removeslave taskadmin \
 || :
fi

%triggerin -n python27-boto -- python27
# Refresh alternatives when updating python27-boto or python27.
%{_sbindir}/update-alternatives \
  --force \
  --update python %{_bindir}/python2.7 \
  --addslave %{_bindir}/asadmin asadmin %{_bindir}/asadmin-2.7 \
  --addslave %{_bindir}/bundle_image bundle_image %{_bindir}/bundle_image-2.7 \
  --addslave %{_bindir}/cfadmin cfadmin %{_bindir}/cfadmin-2.7 \
  --addslave %{_bindir}/cq cq %{_bindir}/cq-2.7 \
  --addslave %{_bindir}/cwutil cwutil %{_bindir}/cwutil-2.7 \
  --addslave %{_bindir}/dynamodb_dump dynamodb_dump %{_bindir}/dynamodb_dump-2.7 \
  --addslave %{_bindir}/dynamodb_load dynamodb_load %{_bindir}/dynamodb_load-2.7 \
  --addslave %{_bindir}/elbadmin elbadmin %{_bindir}/elbadmin-2.7 \
  --addslave %{_bindir}/fetch_file fetch_file %{_bindir}/fetch_file-2.7 \
  --addslave %{_bindir}/glacier glacier %{_bindir}/glacier-2.7 \
  --addslave %{_bindir}/instance_events instance_events %{_bindir}/instance_events-2.7 \
  --addslave %{_bindir}/kill_instance kill_instance %{_bindir}/kill_instance-2.7 \
  --addslave %{_bindir}/launch_instance launch_instance %{_bindir}/launch_instance-2.7 \
  --addslave %{_bindir}/list_instances list_instances %{_bindir}/list_instances-2.7 \
  --addslave %{_bindir}/lss3 lss3 %{_bindir}/lss3-2.7 \
  --addslave %{_bindir}/mturk mturk %{_bindir}/mturk-2.7 \
  --addslave %{_bindir}/pyami_sendmail pyami_sendmail %{_bindir}/pyami_sendmail-2.7 \
  --addslave %{_bindir}/route53 route53 %{_bindir}/route53-2.7 \
  --addslave %{_bindir}/s3put s3put %{_bindir}/s3put-2.7 \
  --addslave %{_bindir}/sdbadmin sdbadmin %{_bindir}/sdbadmin-2.7 \
  --addslave %{_bindir}/taskadmin taskadmin %{_bindir}/taskadmin-2.7 \
  || :

%preun -n python27-boto
if [ $1 -eq 0 ]; then
  %{_sbindir}/update-alternatives \
    --update python %{_bindir}/python2.7 \
    --removeslave asadmin \
    --removeslave bundle_image \
    --removeslave cfadmin \
    --removeslave cq \
    --removeslave cwutil \
    --removeslave dynamodb_dump \
    --removeslave dynamodb_load \
    --removeslave elbadmin \
    --removeslave fetch_file \
    --removeslave glacier \
    --removeslave instance_events \
    --removeslave kill_instance \
    --removeslave launch_instance \
    --removeslave list_instances \
    --removeslave lss3 \
    --removeslave mturk \
    --removeslave pyami_sendmail \
    --removeslave route53 \
    --removeslave s3put \
    --removeslave sdbadmin \
    --removeslave taskadmin \
 || :
fi

%files -n python26-boto
%{python26_sitelib}/*
%{_bindir}/asadmin-2.6
%{_bindir}/bundle_image-2.6
%{_bindir}/cfadmin-2.6
%{_bindir}/cq-2.6
%{_bindir}/cwutil-2.6
%{_bindir}/dynamodb_dump-2.6
%{_bindir}/dynamodb_load-2.6
%{_bindir}/elbadmin-2.6
%{_bindir}/fetch_file-2.6
%{_bindir}/glacier-2.6
%{_bindir}/instance_events-2.6
%{_bindir}/kill_instance-2.6
%{_bindir}/launch_instance-2.6
%{_bindir}/list_instances-2.6
%{_bindir}/lss3-2.6
%{_bindir}/mturk-2.6
%{_bindir}/pyami_sendmail-2.6
%{_bindir}/route53-2.6
%{_bindir}/s3put-2.6
%{_bindir}/sdbadmin-2.6
%{_bindir}/taskadmin-2.6
%ghost %{_bindir}/asadmin
%ghost %{_bindir}/bundle_image
%ghost %{_bindir}/cfadmin
%ghost %{_bindir}/cq
%ghost %{_bindir}/cwutil
%ghost %{_bindir}/dynamodb_dump
%ghost %{_bindir}/dynamodb_load
%ghost %{_bindir}/elbadmin
%ghost %{_bindir}/fetch_file
%ghost %{_bindir}/glacier
%ghost %{_bindir}/instance_events
%ghost %{_bindir}/kill_instance
%ghost %{_bindir}/launch_instance
%ghost %{_bindir}/list_instances
%ghost %{_bindir}/lss3
%ghost %{_bindir}/mturk
%ghost %{_bindir}/pyami_sendmail
%ghost %{_bindir}/route53
%ghost %{_bindir}/s3put
%ghost %{_bindir}/sdbadmin
%ghost %{_bindir}/taskadmin

%files -n python27-boto
%{python27_sitelib}/*
%{_bindir}/asadmin-2.7
%{_bindir}/bundle_image-2.7
%{_bindir}/cfadmin-2.7
%{_bindir}/cq-2.7
%{_bindir}/cwutil-2.7
%{_bindir}/dynamodb_dump-2.7
%{_bindir}/dynamodb_load-2.7
%{_bindir}/elbadmin-2.7
%{_bindir}/fetch_file-2.7
%{_bindir}/glacier-2.7
%{_bindir}/instance_events-2.7
%{_bindir}/kill_instance-2.7
%{_bindir}/launch_instance-2.7
%{_bindir}/list_instances-2.7
%{_bindir}/lss3-2.7
%{_bindir}/mturk-2.7
%{_bindir}/pyami_sendmail-2.7
%{_bindir}/route53-2.7
%{_bindir}/s3put-2.7
%{_bindir}/sdbadmin-2.7
%{_bindir}/taskadmin-2.7
%ghost %{_bindir}/asadmin
%ghost %{_bindir}/bundle_image
%ghost %{_bindir}/cfadmin
%ghost %{_bindir}/cq
%ghost %{_bindir}/cwutil
%ghost %{_bindir}/dynamodb_dump
%ghost %{_bindir}/dynamodb_load
%ghost %{_bindir}/elbadmin
%ghost %{_bindir}/fetch_file
%ghost %{_bindir}/glacier
%ghost %{_bindir}/instance_events
%ghost %{_bindir}/kill_instance
%ghost %{_bindir}/launch_instance
%ghost %{_bindir}/list_instances
%ghost %{_bindir}/lss3
%ghost %{_bindir}/mturk
%ghost %{_bindir}/pyami_sendmail
%ghost %{_bindir}/route53
%ghost %{_bindir}/s3put
%ghost %{_bindir}/sdbadmin
%ghost %{_bindir}/taskadmin

%changelog
* Mon Aug 15 2016 Ian Weller <iweller@amazon.com>
- Update to 2.42.0

* Thu Feb 18 2016 Matt Nierzwicki <nierzwic@amazon.com>
- Update to 2.39.0 from upstream

* Thu Apr 16 2015 Jason Green <jasg@amazon.com>
- update to 2.38.0 from upstream

* Mon Mar 2 2015 Ben Cressey <bcressey@amazon.com>
- add alternatives for boto

* Mon Feb 9 2015 hpetty <hpetty@amazon.com>
- update to 2.36.0 from upstream

* Fri Feb 6 2015 Ben Cressey <bcressey@amazon.com>
- fix python version requirement in scripts

* Thu Feb 5 2015 Tom Kirchner <tjk@amazon.com>
- Build for multiple python versions

* Thu Jan 22 2015 hpetty <hpetty@amazon.com>
- update to 2.35.2 from upstream

* Mon Jan 12 2015 Lee Trager <ltrager@amazon.com>
- Update to 2.35.1 from upstream

* Fri Jan 9 2015 Lee Trager <ltrager@amazon.com>
- Update to 2.35.0 from upstream

* Tue Oct 21 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.34.0

* Thu Oct 9 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.33.0 from upstream

* Tue Aug 19 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.32.1 from upstream

* Thu Jul 31 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.32.0 from upstream

* Tue Jul 29 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.31.1 from upstream

* Wed Jul 2 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.30.0 from upstream

* Tue Jun 10 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.29.1 from upstream

* Fri May 9 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.28.0 from upstream

* Fri Mar 7 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.27.0 from upstream

* Wed Mar 5 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.26.1 from upstream

* Thu Feb 27 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.25.0 from upstream

* Mon Feb 3 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.24.0 from upstream

* Mon Jan 13 2014 Lee Trager <ltrager@amazon.com>
- Update to 2.23.0 from upstream

* Tue Dec 17 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.20.1 from upstream

* Tue Dec 3 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.19.0 from upstream

* Thu Nov 14 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.17.0 from upstream

* Sat Nov 9 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.16.0 from upstream

* Tue Oct 22 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.15.0 from upstream

* Wed Oct 16 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.14.0 from upstream

* Tue Sep 17 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.13.3 from upstream

* Fri Sep 13 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.13.0 from upstream

* Tue Sep 10 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.12.0 from upstream

* Fri Aug 30 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.11.0 from upstream

* Tue Jul 30 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.9.9 from upstream

* Mon Jul 22 2013 Lee Trager <ltrager@amazon.com>
- Update to boto 2.9.8 from upstream

* Wed Jul 10 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.9.7 from upstream

* Wed Jun 19 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.9.6 from upstream

* Mon Jun 10 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.9.5 from upstream

* Thu May 23 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.9.4 from upstream

* Tue May 7 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.9.2 from upstream

* Thu Apr 18 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.9.0 from upstream

* Fri Feb 1 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.8.0 from upstream and change homepage

* Mon Jan 14 2013 Lee Trager <ltrager@amazon.com>
- Update to 2.7.0 from upstream

* Fri Sep 21 2012 Lee Trager <ltrager@amazon.com>
- Add optional checks section
- Update to 2.6.0 from upstream

* Mon Jun 25 2012 Lee Trager <ltrager@amazon.com>
- Update to 2.5.2 from upstream

* Thu Jun 14 2012 Lee Trager <ltrager@amazon.com>
- Update to 2.5.1 from upstream

* Wed Jun 13 2012 Lee Trager <ltrager@amazon.com>
- Update Boto to 2.5.0 from upstream

* Wed May 23 2012 Lee Trager <ltrager@amazon.com>
- Update to the latest release from upstream

* Mon Apr 23 2012 Lee Trager <ltrager@amazon.com>
- Update to the latest upstream version

* Thu Mar 08 2012 Andrew Jorgensen <ajorgens@amazon.com> - 2.2.2-0
- update to 2.2.2

* Thu Mar 8 2012 Andrew Jorgensen <ajorgens@amazon.com>
- Update to 2.2.2

* Fri Dec  9 2011 Cristian Gafton <gafton@amazon.com> - 2.1.1-0
- update to 2.1.1

* Fri Dec 9 2011 Cristian Gafton <gafton@amazon.com>
- add cherry-picked patches
- update to version 2.1.1

* Fri Aug 26 2011 Cristian Gafton <gafton@amazon.com> - 2.0-0
- updated to version 2.0

* Fri Aug 26 2011 Cristian Gafton <gafton@amazon.com>
- add patches from the 2.0_stable branch
- update to version 2.0

* Tue Jan 11 2011 Cristian Gafton <gafton@amazon.com>
- allow building in trees that do not have sistem-wide python macros

* Wed Jul 14 2010 Cristian Gafton <gafton@amazon.com>
- use system python macros ; rebuild
- import source package GOBI/python-boto-1.9b-2.fc12
- import source package GOBI/python-boto-1.8d-1.fc12
- import source package GOBI/python-boto-1.5c-2.fc11
- setup complete for package python-boto

* Tue Feb 09 2010 Robert Scheck <robert@fedoraproject.org> 1.9b-2
- Backported upstream patch for image registration (#561216)

* Sat Jan 09 2010 Robert Scheck <robert@fedoraproject.org> 1.9b-1
- Upgrade to 1.9b

* Fri Jul 24 2009 Robert Scheck <robert@fedoraproject.org> 1.8d-1
- Upgrade to 1.8d (#513560)

* Wed Jun 03 2009 Luke Macken <lmacken@redhat.com> 1.7a-2
- Add python-setuptools-devel to our build requirements, for egg-info

* Thu Apr 16 2009 Robert Scheck <robert@fedoraproject.org> 1.7a-1
- Upgrade to 1.7a

* Mon Feb 23 2009 Robert Scheck <robert@fedoraproject.org> 1.5c-2
- Rebuild against rpm 4.6

* Sun Dec 07 2008 Robert Scheck <robert@fedoraproject.org> 1.5c-1
- Upgrade to 1.5c

* Fri Dec 05 2008 Jeremy Katz <katzj@redhat.com> 1.2a-2
- Rebuild for python 2.6

* Wed May 07 2008 Robert Scheck <robert@fedoraproject.org> 1.2a-1
- Upgrade to 1.2a

* Sat Feb 09 2008 Robert Scheck <robert@fedoraproject.org> 1.0a-1
- Upgrade to 1.0a

* Sat Dec 08 2007 Robert Scheck <robert@fedoraproject.org> 0.9d-1
- Upgrade to 0.9d

* Thu Aug 30 2007 Robert Scheck <robert@fedoraproject.org> 0.9b-1
- Upgrade to 0.9b
- Initial spec file for Fedora and Red Hat Enterprise Linux
